==> zio-aws-securityhub_2.13-5.17.124.2-sources.jar: zio/aws/securityhub/model/IpOrganizationDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{NonEmptyString, Integer}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class IpOrganizationDetails(
    asn: Option[Integer] = None,
    asnOrg: Option[NonEmptyString] = None,
    isp: Option[NonEmptyString] = None,
    org: Option[NonEmptyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails = {
    import IpOrganizationDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails
      .builder()
      .optionallyWith(
        asn.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.asn)
      .optionallyWith(
        asnOrg.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.asnOrg)
      .optionallyWith(
        isp.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.isp)
      .optionallyWith(
        org.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.org)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.IpOrganizationDetails.ReadOnly =
    zio.aws.securityhub.model.IpOrganizationDetails.wrap(buildAwsValue())
}
object IpOrganizationDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.IpOrganizationDetails =
      zio.aws.securityhub.model.IpOrganizationDetails(
        asn.map(value => value),
        asnOrg.map(value => value),
        isp.map(value => value),
        org.map(value => value)
      )
    def asn: Option[Integer]
    def asnOrg: Option[NonEmptyString]
    def isp: Option[NonEmptyString]
    def org: Option[NonEmptyString]
    def getAsn: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("asn", asn)
    def getAsnOrg: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("asnOrg", asnOrg)
    def getIsp: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("isp", isp)
    def getOrg: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("org", org)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails
  ) extends zio.aws.securityhub.model.IpOrganizationDetails.ReadOnly {
    override val asn: Option[Integer] = scala
      .Option(impl.asn())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
    override val asnOrg: Option[NonEmptyString] = scala
      .Option(impl.asnOrg())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val isp: Option[NonEmptyString] = scala
      .Option(impl.isp())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val org: Option[NonEmptyString] = scala
      .Option(impl.org())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails
  ): zio.aws.securityhub.model.IpOrganizationDetails.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-securityhub_2.13-5.17.148.1-sources.jar: zio/aws/securityhub/model/IpOrganizationDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{NonEmptyString, Integer}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class IpOrganizationDetails(
    asn: Option[Integer] = None,
    asnOrg: Option[NonEmptyString] = None,
    isp: Option[NonEmptyString] = None,
    org: Option[NonEmptyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails = {
    import IpOrganizationDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails
      .builder()
      .optionallyWith(asn.map(value => value: java.lang.Integer))(_.asn)
      .optionallyWith(
        asnOrg.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.asnOrg)
      .optionallyWith(
        isp.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.isp)
      .optionallyWith(
        org.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.org)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.IpOrganizationDetails.ReadOnly =
    zio.aws.securityhub.model.IpOrganizationDetails.wrap(buildAwsValue())
}
object IpOrganizationDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.IpOrganizationDetails =
      zio.aws.securityhub.model.IpOrganizationDetails(
        asn.map(value => value),
        asnOrg.map(value => value),
        isp.map(value => value),
        org.map(value => value)
      )
    def asn: Option[Integer]
    def asnOrg: Option[NonEmptyString]
    def isp: Option[NonEmptyString]
    def org: Option[NonEmptyString]
    def getAsn: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("asn", asn)
    def getAsnOrg: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("asnOrg", asnOrg)
    def getIsp: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("isp", isp)
    def getOrg: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("org", org)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails
  ) extends zio.aws.securityhub.model.IpOrganizationDetails.ReadOnly {
    override val asn: Option[Integer] =
      scala.Option(impl.asn()).map(value => value: Integer)
    override val asnOrg: Option[NonEmptyString] = scala
      .Option(impl.asnOrg())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val isp: Option[NonEmptyString] = scala
      .Option(impl.isp())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val org: Option[NonEmptyString] = scala
      .Option(impl.org())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.IpOrganizationDetails
  ): zio.aws.securityhub.model.IpOrganizationDetails.ReadOnly = new Wrapper(
    impl
  )
}
